@@ -84,13 +84,7 @@ class ICamera(ABC):
         :param format: the new data format (for OpenCV time scale is fixed, for other devices is microseconds)
         :type exposure: str
         """
-        pass
-
-    @abstractmethod
-    def get_pixel_format(self):
-        """Returns the current camera pixel format.
-        """
-        pass    
+        pass 
 
     @abstractmethod
     def set_exposure(self, exposure) -> None:
